import { test } from 'tape';
import {
    findMatches,
    findMatchesHtml,
    findMatchesNormalized,
    findMatchesHtmlNormalized,
} from '../src/examples/index';

test('Lucid finds the correct matches', (t) => {
    const haystack = 'The quick brown fox jumps over the lazy dog';
    const needle = 'The dog barks';
    const found = findMatches(haystack, needle);

    t.deepEquals(found.matches, ['The', 'the', 'dog']);
    t.equals(found.matches.length, 3);
    t.end();
});

test('Lucid handles empty strings correctly', (t) => {
    const haystack = 'The quick brown fox jumps over the lazy dog';
    const needle = '     The       dog      barks      ';
    const found1 = findMatches(haystack, needle);
    const found2 = findMatches(haystack, '    ');

    t.deepEquals(found1.matches, ['The', 'the', 'dog']);
    t.deepEquals(found2.matches, []);
    t.end();
});

test('Lucid finds the correct emojis', (t) => {
    const haystack = '😋 😛 😝 😜 🤪 🤨 🧐 🤓 😎';
    const needle = '😎';
    const found = findMatches(haystack, needle);

    t.deepEquals(found.matches, ['😎']);
    t.equals(found.matches.length, 1);
    t.end();
});

test('Lucid highlights correctly', (t) => {
    const haystack = 'The quick brown fox jumps over the lazy dog';
    const needle = 'The dog barks';
    const found = findMatches(haystack, needle);

    t.equals(found.mark, '<span class="matched">The</span> quick brown fox jumps over <span class="matched">the</span> lazy <span class="matched">dog</span>');
    t.end();
});

test('Lucid highlights correctly with options', (t) => {
    const haystack = 'The quick brown fox jumps over the lazy dog';
    const needle = 'The dog barks';
    const options = { el: 'mark', cssClass: 'found' };
    const found = findMatches(haystack, needle, options);

    t.equals(found.mark, '<mark class="found">The</mark> quick brown fox jumps over <mark class="found">the</mark> lazy <mark class="found">dog</mark>');
    t.end();
});

test('Lucid finds the correct matches in HTML string', (t) => {
    const haystack = 'The quick brown <strong>fox</strong> jumps over the lazy <div>dog</div>';
    const needle = 'The dog strong div';
    const found = findMatchesHtml(haystack, needle);

    t.deepEquals(found.matches, ['The', 'the', 'dog']);
    t.equals(found.matches.length, 3);
    t.end();
});

test('Lucid highlights HTML strings correctly', (t) => {
    const haystack = 'The quick brown <strong>fox</strong> jumps over the lazy <div>dog</div>';
    const needle = 'The dog strong div';
    const found = findMatchesHtml(haystack, needle);

    t.equals(found.mark, '<span class="matched">The</span> quick brown <strong>fox</strong> jumps over <span class="matched">the</span> lazy <div><span class="matched">dog</span></div>');
    t.end();
});

test('Lucid highlights nested HTML strings correctly', (t) => {
    const haystack = 'The quick brown <strong>fox</strong> jumps over the lazy <div><nav><strong>dog</strong></nav></div>';
    const needle = 'The dog strong div nav';
    const found = findMatchesHtml(haystack, needle);

    t.equals(found.mark, '<span class="matched">The</span> quick brown <strong>fox</strong> jumps over <span class="matched">the</span> lazy <div><nav><strong><span class="matched">dog</span></strong></nav></div>');
    t.equals(found.matches.length, 3);
    t.end();
});

test('Lucid finds the correct matches with special characters like äöüè', (t) => {
    const haystack = 'Thé quīçk brown føx jümps over the låzy dog';
    const needle = 'Thë dog barkß';
    const found = findMatchesNormalized(haystack, needle);

    t.deepEquals(found.matches, ['Thé', 'the', 'dog']);
    t.equals(found.matches.length, 3);
    t.end();
});

test('Lucid highlights HTML strings correctly with special characters like äöüè', (t) => {
    const haystack = 'Thé quīçk brown <strong>føx</strong> jümps over the låzy <div>dog</div>';
    const needle = 'The dog strong div';
    const found = findMatchesHtmlNormalized(haystack, needle);

    t.equals(found.mark, '<span class="matched">Thé</span> quīçk brown <strong>føx</strong> jümps over <span class="matched">the</span> låzy <div><span class="matched">dog</span></div>');
    t.end();
});

test('Lucid highlights HTML strings correctly with special characters like äöüè', (t) => {
    const haystack = 'Thé quīçk brown <strong>føx</strong> jümps over the låzy <div>dog</div>';
    const needle = 'The dog strong div';
    const found = findMatchesHtmlNormalized(haystack, needle);

    t.deepEquals(found.matches, ['Thé', 'the', 'dog']);
    t.equals(found.matches.length, 3);
    t.end();
});
